;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ultra-scroll" "0.5"
  "Fast and smooth scrolling."
  '((emacs "29.1"))
  :url "https://github.com/jdtsmith/ultra-scroll"
  :commit "21c568b1a26e597714ad65b40f246dd6e9f71fdd"
  :revdesc "21c568b1a26e"
  :keywords '("convenience"))
